@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/ahyatt/triples
 ;; Package-Requires: ((seq "2.0") (emacs "28.1"))
 ;; Keywords: triples, kg, data, sqlite
-;; Version: 0.3.4
+;; Version: 0.3.5
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation; either version 2 of the
@@ -33,9 +33,16 @@
 (require 'package)
 (require 'seq)
 (require 'subr-x)
+(require 'emacsql nil t)
 
 ;;; Code:
 
+(defvar emacsql-sqlite-executable)
+(declare-function emacsql-with-transaction "emacsql")
+(declare-function emacsql-close "emacsql")
+(declare-function emacsql-sqlite "emacsql")
+(declare-function emacsql "emacsql")
+
 (defvar triples-sqlite-interface
   (if (and (fboundp 'sqlite-available-p) (sqlite-available-p))
       'builtin
@@ -54,6 +61,12 @@ It is invoked to make backups.")
   "The default filename triples database. If no database is
 specified, this file is used.")
 
+(defmacro triples-with-transaction (db &rest body)
+  "Create a transaction using DB, executing BODY.
+The transaction will abort if an error is thrown."
+  (declare (indent 0) (debug t))
+  `(triples--with-transaction ,db (lambda () ,@body)))
+
 (defun triples-rebuild-builtin-database (db)
   "Rebuild the builtin database DB.
 This is used in upgrades and when problems are detected."
@@ -135,8 +148,11 @@ upgrades to version 0.3"
     ('builtin (sqlite-close db))
     ('emacsql (emacsql-close db))))
 
-(defun triples-backup (db filename num-to-keep)
-  "Perform a backup of DB, located at path FILENAME.
+(defun triples-backup (_ filename num-to-keep)
+  "Perform a backup of the db, located at path FILENAME.
+The first argument is unused, but later may be used to specify
+the running database.
+
 This uses the same backup location and names as configured in
 variables such as `backup-directory-alist'. Due to the fact that
 the database is never opened as a buffer, normal backups will not
@@ -518,12 +534,6 @@ PROPERTIES is a plist of properties, without TYPE prefixes."
                      (cdr c))) prop-schema-alist))
     (triples--add db op)))
 
-(defmacro triples-with-transaction (db &rest body)
-  "Create a transaction using DB, executing BODY.
-The transaction will abort if an error is thrown."
-  (declare (indent 0) (debug t))
-  `(triples--with-transaction ,db (lambda () ,@body)))
-
 (defmacro triples--eval-when-fboundp (sym form)
   "Delay macroexpansion to runtime if SYM is not yet `fboundp'."
   (declare (indent 1) (debug (symbolp form)))
